@@ -1,3 +1,3 @@
-video_extensions = (".avi",)
+video_extensions = (".avi", ".mp4")
 config_extension = ".json"
 results_extension = ".h5"
